# SunTzu
**SunTzu** is a simple Python library that built on top of pandas and numpy to make simple pre data analysis procedures.
Like:
- Finding optimal dtypes for each column
- Quickly see memory usage
- Turn 2-value columns into `bool` to save memory
- Quickly see max, min, null, unique values of your dataframe

## 📑 Table of Contents

- [How to install it](#how-to-install-it)
- [Inside the Project](#-inside-the-project)
    - [What I learned](#-what-i-learned)
    - [Libraries Used](#libraries-used)
- [License](#license)
- [Credits](#credits)
    

## 📦 How to install it?
Currently, you can find:
 - Source code: [GitHub Repository](https://github.com/Abigor111/SunTzu)
 - Documentation: [Read the Docs](https://suntzu.readthedocs.io/en/latest/index.html)
 - Latest Versions: [PyPI](https://pypi.org/project/suntzu/#history)

To install it open your terminal with Python installed and use:
```sh
pip install suntzu
```
If you want to install a specific version use:
```sh
pip install suntzu==specific_version
```
## 🔧 Inside The Project

This project was my 12th grade final project. I chose to build it to explore how Python packages are created. It was an ambitious project and I learned a lot throughout the process. In the end, it received the highest possible grade.

### 📚 What I Learned
- OOP Concepts
- Python Package Distribution
- Creating documention for Python Packages
---
### 💻 Technologies Used
- [pandas](https://pypi.org/project/pandas/)
- [numpy](https://pypi.org/project/numpy/)
---

### 🚀 Future Steps
This project was later revamped. The original version had a poor OOP structure and accessing the functions was much harder than it should’ve been. It also included visualization and metadata features, which I decided to split into separate libraries. Once those libraries are finished, I’ll link them here.
## 📜 License
[MIT](LICENSE)

## 🙌 Credits
 - This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [`audreyr/cookiecutter-pypackage`](https://github.com/audreyr/cookiecutter-pypackage) project template.
